==> haskell-minimorph-0.3.0.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-minimorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 minimorph
version:              0.3.0.1
visibility:           public
id:                   minimorph-0.3.0.1-GzgxjbEc7gG54Swn8GlpWo
key:                  minimorph-0.3.0.1-GzgxjbEc7gG54Swn8GlpWo
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Eric Kow
homepage:             https://github.com/Mikolaj/minimorph
synopsis:             English spelling functions with an emphasis on simplicity.
description:
    A set of simplistic functions capturing the more regular
    parts of English spelling (for generation, not parsing).
    You will need to complement this with some account for
    irregular nouns/verbs. This package is not meant to provide
    anything resembling a full account of English morphology
    (something like Functional Morphology or sequor could be
    better suited). The main goal is to provide something cheap
    and cheerful with no learning curve, that you can use until
    your application calls for more robustness.
    See <https://github.com/Mikolaj/miniutter> for a simple
    use case.

category:             Natural Language Processing
abi:                  44305a414ce5c651b0e57f2d8e192799
exposed:              True
exposed-modules:
    NLP.Minimorph.English NLP.Minimorph.Number NLP.Minimorph.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/minimorph-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/minimorph-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-minimorph
hs-libraries:         HSminimorph-0.3.0.1-GzgxjbEc7gG54Swn8GlpWo
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-minimorph/html/minimorph.haddock
haddock-html:         /usr/share/doc/haskell-minimorph/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-minimorph-0.3.0.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-minimorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 minimorph
version:              0.3.0.1
visibility:           public
id:                   minimorph-0.3.0.1-3X8y9EjkJ6ME9gL8BpHriD
key:                  minimorph-0.3.0.1-3X8y9EjkJ6ME9gL8BpHriD
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Eric Kow
homepage:             https://github.com/Mikolaj/minimorph
synopsis:             English spelling functions with an emphasis on simplicity.
description:
    A set of simplistic functions capturing the more regular
    parts of English spelling (for generation, not parsing).
    You will need to complement this with some account for
    irregular nouns/verbs. This package is not meant to provide
    anything resembling a full account of English morphology
    (something like Functional Morphology or sequor could be
    better suited). The main goal is to provide something cheap
    and cheerful with no learning curve, that you can use until
    your application calls for more robustness.
    See <https://github.com/Mikolaj/miniutter> for a simple
    use case.

category:             Natural Language Processing
abi:                  afcab5e3144b5fbc3308ca480f19c5e0
exposed:              True
exposed-modules:
    NLP.Minimorph.English NLP.Minimorph.Number NLP.Minimorph.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/minimorph-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/minimorph-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-minimorph
hs-libraries:         HSminimorph-0.3.0.1-3X8y9EjkJ6ME9gL8BpHriD
depends:              base-4.16.4.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-minimorph/html/minimorph.haddock
haddock-html:         /usr/share/doc/haskell-minimorph/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
